@@ -4,14 +4,11 @@
 #  --> https://CRAN.R-project.org/package=spam              #
 #  --> https://CRAN.R-project.org/package=spam64            #
 #  --> https://git.math.uzh.ch/reinhard.furrer/spam         #
-# by Reinhard Furrer [aut, cre], Florian Gerber [ctb],      #
-#    Roman Flury [ctb], Daniel Gerber [ctb],                #
+# by Reinhard Furrer [aut, cre], Florian Gerber [aut],      #
+#    Roman Flury [aut], Daniel Gerber [ctb],                #
 #    Kaspar Moesinger [ctb]                                 #
 # HEADER END ################################################
 
-todo <- function() help( "todo.spam")
-spam.history <- function() help("spam.history")
-
 # We check that
 # 1.  #colindices equals #entries
 # 2.	class(entries) is "numeric"
